summaryrefslogtreecommitdiff
path: root/png.h
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-21 05:51:07 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2014-08-21 05:57:34 -0500
commite73cc88b21d25a6451dbc3e90fc6d60967269820 (patch)
tree06179786547acd3346756ca682191dd064bbf51c /png.h
parent60b6a64975a08aed00b88f43a9e9e83b29f91595 (diff)
downloadlibpng-e73cc88b21d25a6451dbc3e90fc6d60967269820.tar.gz
[libpng15] Imported from libpng-1.5.19.tarv1.5.19
Diffstat (limited to 'png.h')
-rw-r--r--png.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/png.h b/png.h
index ca33f67d1..bf69a0483 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.5.19rc02 - August 14, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.5.19rc02 - August 14, 2014: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -197,7 +197,8 @@
* 1.5.18rc01-02 15 10518 15.so.15.18[.0]
* 1.5.18 15 10518 15.so.15.18[.0]
* 1.5.19beta01-05 15 10519 15.so.15.19[.0]
- * 1.5.19rc01-02 15 10519 15.so.15.19[.0]
+ * 1.5.19rc01 15 10519 15.so.15.19[.0]
+ * 1.5.19 15 10519 15.so.15.19[.0]
*
* Henceforth the source version will match the shared-library major
* and minor numbers; the shared-library major version number will be
@@ -229,7 +230,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.2.6, August 15, 2004, through 1.5.19rc02, August 14, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5
* with the following individual added to the list of Contributing Authors:
@@ -341,13 +342,13 @@
* Y2K compliance in libpng:
* =========================
*
- * August 14, 2014
+ * August 21, 2014
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
*
* This is your unofficial assurance that libpng from version 0.71 and
- * upward through 1.5.19rc02 are Y2K compliant. It is my belief that
+ * upward through 1.5.19 are Y2K compliant. It is my belief that
* earlier versions were also Y2K compliant.
*
* Libpng only has two year fields. One is a 2-byte unsigned integer
@@ -408,9 +409,9 @@
*/
/* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.19rc02"
+#define PNG_LIBPNG_VER_STRING "1.5.19"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.5.19rc02 - August 14, 2014\n"
+ " libpng version 1.5.19 - August 21, 2014\n"
#define PNG_LIBPNG_VER_SONUM 15
#define PNG_LIBPNG_VER_DLLNUM 15
@@ -424,7 +425,7 @@
* PNG_LIBPNG_VER_STRING, omitting any leading zero:
*/
-#define PNG_LIBPNG_VER_BUILD 02
+#define PNG_LIBPNG_VER_BUILD 0
/* Release Status */
#define PNG_LIBPNG_BUILD_ALPHA 1
@@ -441,7 +442,7 @@
#define PNG_LIBPNG_BUILD_SPECIAL 32 /* Cannot be OR'ed with
PNG_LIBPNG_BUILD_PRIVATE */
-#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_RC
+#define PNG_LIBPNG_BUILD_BASE_TYPE PNG_LIBPNG_BUILD_STABLE
/* Careful here. At one time, Guy wanted to use 082, but that would be octal.
* We must not include leading zeros.
@@ -571,7 +572,7 @@ extern "C" {
/* This triggers a compiler error in png.c, if png.c and png.h
* do not agree upon the version number.
*/
-typedef char* png_libpng_version_1_5_19rc02;
+typedef char* png_libpng_version_1_5_19;
/* Three color definitions. The order of the red, green, and blue, (and the
* exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.5.19rc02 - August 14, 2014
+ * libpng version 1.5.19 - August 21, 2014
* Copyright (c) 1998-2014 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.5.19rc02 - August 14, 2014: Glenn
+ * libpng versions 0.97, January 1998, through 1.5.19 - August 21, 2014: Glenn
* See also "Contributing Authors", below.
*
@@ -229,7 +230,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.2.6, August 15, 2004, through 1.5.19rc02, August 14, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.19, August 21, 2014, are
* Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.2.5